# NOTE Patch0 should adapted with our mageia fonts path

Name:          pdfbox
Version:       2.0.23
Release:       %mkrel 1
Group:         Development/Java
Summary:       Apache PDFBox library for working with PDF documents
License:       ASL 2.0
URL:           http://pdfbox.apache.org/
Source0:       http://archive.apache.org/dist/pdfbox/%{version}/pdfbox-%{version}-src.zip

# Use system font instead of bundled font
Patch0:        pdfbox-use-system-liberation-font.patch
# Use system icc profiles
Patch1:        pdfbox-use-system-icc-profiles-openicc.patch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.bouncycastle:bcmail-jdk15on)
BuildRequires:  mvn(org.bouncycastle:bcprov-jdk15on)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(jakarta.activation:jakarta.activation-api)

BuildRequires: fonts-ttf-dejavu
BuildRequires: google-noto-emoji-fonts
BuildRequires: fonts-ttf-liberation
BuildRequires: icc-profiles-openicc
BuildRequires: fontconfig
Requires:      fonts-ttf-liberation

# TODO: Require liberation-sans-fonts >= 2 and don't ignore test failures

BuildArch:     noarch

# Ant support was removed by upstream (Obsoletes added in F28)
Obsoletes:     %{name}-ant < %{version}-%{release}
# Jempbox subproject was removed by upstream (Obsoletes added in F28)
Obsoletes:     jempbox < %{version}-%{release}
# Examples package was dropped due to requiring too old lucene (Obsoletes added in F29)
Obsoletes:     %{name}-examples < %{version}-%{release}

%description
Apache PDFBox is an open source Java PDF library for working with PDF
documents. This project allows creation of new PDF documents, manipulation of
existing documents and the ability to extract content from documents. Apache
PDFBox also includes several command line utilities. Apache PDFBox is
published under the Apache License v2.0.

%package debugger
Summary:       Apache PDFBox Debugger

%description debugger
This package contains the PDF debugger for Apache PDFBox.

%package tools
Summary:       Apache PDFBox Tools

%description tools
This package contains command line tools for Apache PDFBox.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%package -n fontbox
Summary:        Apache FontBox

%description -n fontbox
FontBox is a Java library used to obtain low level information from font
files. FontBox is a subproject of Apache PDFBox.

%package parent
Summary:        Apache PDFBox Parent POM

%description parent
Apache PDFBox Parent POM.

%package reactor
Summary:        Apache PDFBox Reactor POM

%description reactor
Apache PDFBox Reactor POM.

%package -n preflight
Summary:        Apache Preflight

%description -n preflight
The Apache Preflight library is an open source Java tool that implements 
a parser compliant with the ISO-19005 (PDF/A) specification. Preflight is a 
subproject of Apache PDFBox.

%package -n xmpbox
Summary:        Apache XmpBox

%description -n xmpbox
The Apache XmpBox library is an open source Java tool that implements Adobe's
XMP(TM) specification.  It can be used to parse, validate and create xmp
contents.  It is mainly used by subproject preflight of Apache PDFBox. 
XmpBox is a subproject of Apache PDFBox.

%prep
%setup -q
find -name '*.class' -delete
find -name '*.jar' -delete
find -name 'sRGB.icc*' -print -delete
find -name '*.icm' -print -delete
find -name '*.ttf' -print -delete

%patch0 -p1 -b .font
%patch1 -b .openicc

# Don't build apps (it's just a bundle of everything)
%pom_disable_module preflight-app
%pom_disable_module debugger-app
%pom_disable_module app

# Don't build examples, they require ancient version of lucene
%pom_disable_module examples

# Disable plugins not needed for RPM builds
%pom_remove_plugin -r :animal-sniffer-maven-plugin
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-deploy-plugin
%pom_remove_plugin -r :maven-release-plugin
%pom_remove_plugin -r :maven-source-plugin
%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin

# Some test resources are not okay to distribute with the source, upstream
# downloads them at build time, but we can't, so we either remove or fix
# the affected tests
%pom_remove_plugin -r :download-maven-plugin
rm fontbox/src/test/java/org/apache/fontbox/cff/CFFParserTest.java \
   pdfbox/src/test/java/org/apache/pdfbox/pdfparser/TestPDFParser.java \
   pdfbox/src/test/resources/input/rendering/{FANTASTICCMYK.ai,HOTRODCMYK.ai} \
   preflight/src/test/java/org/apache/pdfbox/preflight/TestIsartorBavaria.java
ln -s %{_datadir}/fonts/TTF/liberation/LiberationSans-Regular.ttf pdfbox/src/test/resources/org/apache/pdfbox/ttf/LiberationSans-Regular.ttf
sed -i -e 's/\(testCIDFontType2VerticalSubset\)/ignore_\1/' pdfbox/src/test/java/org/apache/pdfbox/pdmodel/font/TestFontEmbedding.java
sed -i -e 's/\(testStructureTreeMerge\)/ignore_\1/'  pdfbox/src/test/java/org/apache/pdfbox/multipdf/PDFMergerUtilityTest.java
sed -i -e '/testPDFBOX4115/i\@org.junit.Ignore' pdfbox/src/test/java/org/apache/pdfbox/pdmodel/font/PDFontTest.java

# Remove unpackaged test deps and tests that rely on them
%pom_remove_dep -r com.github.jai-imageio:
%pom_remove_dep -r :jbig2-imageio
rm tools/src/test/java/org/apache/pdfbox/tools/imageio/TestImageIOUtils.java
%pom_remove_dep :diffutils pdfbox
rm pdfbox/src/test/java/org/apache/pdfbox/text/TestTextStripper.java
sed -i -e 's/TestTextStripper/BidiTest/' pdfbox/src/test/java/org/apache/pdfbox/text/BidiTest.java

# Remove tests that otherwise require net connectivity
rm pdfbox/src/test/java/org/apache/pdfbox/multipdf/MergeAcroFormsTest.java \
   pdfbox/src/test/java/org/apache/pdfbox/multipdf/MergeAnnotationsTest.java
sed -i -e '/\(OptionsAndNamesNotNumbers\|RadioButtonWithOptions\)/i\@org.junit.Ignore' \
  pdfbox/src/test/java/org/apache/pdfbox/pdmodel/interactive/form/PDButtonTest.java

# These test fail for unknown reasons
rm pdfbox/src/test/java/org/apache/pdfbox/pdmodel/graphics/image/CCITTFactoryTest.java

# install all libraries in _javadir
%mvn_file :%{name} %{name}
%mvn_file :%{name}-debugger %{name}-debugger
%mvn_file :%{name}-examples %{name}-examples
%mvn_file :%{name}-tools %{name}-tools
%mvn_file :preflight preflight
%mvn_file :xmpbox xmpbox
%mvn_file :fontbox fontbox

%pom_add_dep jakarta.activation:jakarta.activation-api

%build
# Integration tests all require internet access to download test resources, so skip
# Use compat version of lucene
# Ignore test failures on F28 and earlier due to liberation fonts being too old
%mvn_build -s -- -DskipITs -Dlucene.version=4 -Dmaven.test.failure.ignore=true

%install
%mvn_install

%files -f .mfiles-%{name}
%doc README.md RELEASE-NOTES.txt

%files debugger -f .mfiles-%{name}-debugger

%files tools -f .mfiles-%{name}-tools

%files -n fontbox -f .mfiles-fontbox
%doc fontbox/README.txt
%license LICENSE.txt NOTICE.txt

%files parent -f .mfiles-%{name}-parent
%license LICENSE.txt NOTICE.txt

%files reactor -f .mfiles-%{name}-reactor
%license LICENSE.txt NOTICE.txt

%files -n preflight -f .mfiles-preflight
%doc preflight/README.txt

%files -n xmpbox -f .mfiles-xmpbox
%doc xmpbox/README.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Sat Apr 03 2021 neoclust <neoclust> 2.0.23-1.mga8
+ Revision: 1712880
- Add P100: Fixes CVE-2020-13936 (mga#28681)

* Mon Jan 11 2021 daviddavid <daviddavid> 2.0.21-2.mga8
+ Revision: 1671014
- add upstream patch to fix build with bouncycastle 1.67
+ neoclust <neoclust>
- Drop log4j12 dependency, it seems to not be necessary any longer.

* Thu Sep 03 2020 daviddavid <daviddavid> 2.0.21-1.mga8
+ Revision: 1621218
- Update pdfbox to 2.0.21 (#1871001)
- Rebuilt for JDK-11

* Thu Jun 11 2020 joequant <joequant> 2.0.20-1.mga8
+ Revision: 1592530
- update to 2.0.20

* Sun Feb 16 2020 umeabot <umeabot> 2.0.16-2.mga8
+ Revision: 1536143
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 2.0.16-1.mga8
+ Revision: 1453340
- Update to 2.0.16 (CVE-2018-8036, CVE-2018-11797, CVE-2019-0228)

* Tue Dec 04 2018 daviddavid <daviddavid> 2.0.9-3.mga7
+ Revision: 1338195
- Disable examples subpackage that requires obsolete lucene4

* Thu Sep 20 2018 umeabot <umeabot> 2.0.9-2.mga7
+ Revision: 1281520
- Mageia 7 Mass Rebuild

* Fri Aug 24 2018 daviddavid <daviddavid> 2.0.9-1.mga7
+ Revision: 1253706
- new version: 2.0.9 (sync with fc29)

* Thu Oct 05 2017 daviddavid <daviddavid> 1.8.13-1.mga7
+ Revision: 1168984
- update to 1.8.13 (sync with fc27)
- fix rhbz#1421809 (Apply upstream patches to SynchronizedMetaDataValidation)

* Sat May 20 2017 neoclust <neoclust> 1.8.12-1.mga6
+ Revision: 1103714
- New version 1.8.12

* Sat Jul 02 2016 daviddavid <daviddavid> 1.8.11-5.mga6
+ Revision: 1038300
- add upstream patch to fix CVE-2016-2175 (mga#18558)
  * from: http://svn.apache.org/viewvc?view=revision&revision=1739564

* Sat May 14 2016 shlomif <shlomif> 1.8.11-4.mga6
+ Revision: 1015261
- Rebuild for the new UCI (new major)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.8.11-2.mga6
+ Revision: 977766
- First rebuild of the java stack
- sync package pdfbox with fedora
- imported package pdfbox

* Tue Dec 30 2014 daviddavid <daviddavid> 1.8.7-1.mga5
+ Revision: 807269
- Sync with fc21 (update to 1.8.7)
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.7.0-3.mga4
+ Revision: 508925
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.7.0-2.mga3
+ Revision: 362677
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 dmorgan <dmorgan> 1.7.0-1.mga3
+ Revision: 326570
- New version

* Mon Jan 09 2012 gil <gil> 1.6.0-3.mga2
+ Revision: 193617
- build fix
  modified line#157
- build fix
  added system pcfi support
  added system fonts-ttf-bitstream-vera support

* Thu Oct 06 2011 gil <gil> 1.6.0-2.mga2
+ Revision: 152481
- edit spec file
- edit spec file
- rebuilt with mvn, enable javadoc

* Thu Oct 06 2011 dmorgan <dmorgan> 1.6.0-1.mga2
+ Revision: 152446
- Do not build javadoc
- Try to build with ant
- Disable tests ( from gil)
- Add maven-surefire-provider-junit4 as BuildRequires
- Clean spec file
+ gil <gil>
- update to 1.6.0
- imported package pdfbox


* Mon Feb 08 2016 gil cattaneo <puntogil@libero.it> 1.8.11-1
- update to 1.8.11

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Sep 05 2015 gil cattaneo <puntogil@libero.it> 1.8.10-1
- update to 1.8.10

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 24 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.8.8-4
- Remove cobertura-maven-plugin usage from POM
- Resolves: rhbz#1205176

* Wed Feb 11 2015 gil cattaneo <puntogil@libero.it> 1.8.8-3
- introduce license macro

* Mon Jan 19 2015 gil cattaneo <puntogil@libero.it> 1.8.8-2
- rebuilt for regenerate rpm {osgi,maven}.prov, {osgi,maven}.req

* Sat Jan 17 2015 gil cattaneo <puntogil@libero.it> 1.8.8-1
- update to 1.8.8

* Thu Oct 30 2014 gil cattaneo <puntogil@libero.it> 1.8.7-1
- update to 1.8.7

* Fri Sep 26 2014 gil cattaneo <puntogil@libero.it> 1.8.5-3
- build fix for bouncycastle 1.50 (rhbz#1100445)
- adapt to current guideline
- remove lucene sub package
- force log4j12 usage

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 21 2014 Orion Poplawski <orion@cora.nwra.com> - 1.8.5-1
- Add patch to disable test that needs missing deps
- Remove missing test deps from pdbbox pom
- Use junit instead of junit4

* Fri May 2 2014 Orion Poplawski <orion@cora.nwra.com> - 1.8.5-1
- Update to 1.8.5

* Sat Feb 1 2014 Orion Poplawski <orion@cora.nwra.com> - 1.8.4-1
- Update to 1.8.4

* Mon Dec 2 2013 Orion Poplawski <orion@cora.nwra.com> - 1.8.3-1
- Update to 1.8.3
- New pcfi.jar location

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 14 2013 Orion Poplawski <orion@cora.nwra.com> - 1.8.2-1
- Update to 1.8.2
- Drop unneeded maven BRs

* Wed Apr 17 2013 Orion Poplawski <orion@cora.nwra.com> - 1.8.1-1
- Update to 1.8.1

* Thu Mar 28 2013 Orion Poplawski <orion@cora.nwra.com> - 1.8.0-1
- Update to 1.8.0
- Add preflight and xmpbox sub-packages

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 1.7.0-5
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Mon Sep 24 2012 Orion Poplawski <orion@cora.nwra.com> - 1.7.0-4
- Drop lucene sub-package for now, not compatible with lucene 3.6

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul 3 2012 Orion Poplawski <orion@cora.nwra.com> - 1.7.0-2
- Fix javadocs -> javadoc typo

* Tue Jul 3 2012 Orion Poplawski <orion@cora.nwra.com> - 1.7.0-1
- Update to 1.7.0
- Add examples sub-package
- Add BR on bitstream font and fontconfig

* Wed Apr 18 2012 Orion Poplawski <orion@cora.nwra.com> - 1.6.0-5
- Drop pdfbox-app sub-package, nothing but a bundle (bug #813712)

* Wed Feb 1 2012 Orion Poplawski <orion@cora.nwra.com> - 1.6.0-4
- Add proper provides/obsoletes to javadoc sub-package (bug #785396)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 24 2011 Orion Poplawski <orion@cora.nwra.com> - 1.6.0-2
- BR separately packaged pcfi

* Wed Aug 10 2011 Orion Poplawski <orion@cora.nwra.com> - 1.6.0-1
- Update to 1.6.0
- Add pcfi-2010.08.09.jar to sources
- Drop depmap
- Use apache-commons-logging
- Other cleanup

* Fri Jun 3 2011 Orion Poplawski <orion@cora.nwra.com> - 1.5.0-2
- Use maven 3
- Single javadoc package

* Thu Mar 10 2011 Orion Poplawski <orion@cora.nwra.com> - 1.5.0-1
- Update to 1.5.0

* Tue Dec 28 2010 Orion Poplawski <orion@cora.nwra.com> - 1.4.0-2
- Create sub-packages
- Use depmap file

* Tue Dec 21 2010 Orion Poplawski <orion@cora.nwra.com> - 1.4.0-1
- Update to 1.4.0

* Sat Nov 6 2010 Orion Poplawski <orion@cora.nwra.com> - 1.3.1-1
- Update to 1.3.1

* Fri Aug 13 2010 Orion Poplawski <orion@cora.nwra.com> - 1.3.0-0.1
- Update to 1.3.0-SNAPSHOT

* Thu Jul 15 2010 Orion Poplawski <orion@cora.nwra.com> - 1.2.1-1
- Update to 1.2.1

* Thu Jul 1 2010 Orion Poplawski <orion@cora.nwra.com> - 1.2.0-1
- Update to 1.2.0
- Drop gcj support

* Mon Oct 19 2009 Orion Poplawski <orion@cora.nwra.com> - 0.8.0-2
- Add Requires

* Thu Oct 15 2009 Orion Poplawski <orion@cora.nwra.com> - 0.8.0-1
- Initial Fedora package
